<?php
/**
 * ownCloud Firewall
 *
 * @author Joas Schilling <nickvergessen@owncloud.com>
 * @copyright Copyright (c) 2018, ownCloud GmbH
 *
 * This code is covered by the ownCloud Commercial License.
 *
 * You should have received a copy of the ownCloud Commercial License
 * along with this program. If not, see <https://owncloud.com/licenses/owncloud-commercial/>.
 *
 */

namespace OCA\Firewall\Tests\Lib;

use OCA\Firewall\Logger;
use Test\TestCase;

class LoggerTest extends TestCase {

	/** @var \OCP\ILogger|\PHPUnit\Framework\MockObject\MockObject */
	private $logger;

	protected function setUp(): void {
		parent::setUp();

		$this->logger = $this->getMockBuilder('OCP\ILogger')
			->disableOriginalConstructor()
			->getMock();
	}

	public function dataOnPass() {
		return [
			[Logger::LOGGING_OFF, false],
			[Logger::LOGGING_BLOCKS, false],
			[Logger::LOGGING_ON, true],
		];
	}

	/**
	 * @dataProvider dataOnPass
	 *
	 * @param int $logLevel
	 * @param bool $expected
	 */
	public function testOnPass($logLevel, $expected) {
		$logger = new Logger(
			$this->logger,
			$logLevel
		);

		$this->logger->expects($expected ? $this->once() : $this->never())
			->method('info')
			->with('Firewall allowed request', ['app' => 'firewall']);

		$logger->onPass();
	}

	public function dataonBlock() {
		return [
			[Logger::LOGGING_OFF, 'offender1', false],
			[Logger::LOGGING_BLOCKS, 'offender2', true],
			[Logger::LOGGING_ON, 'offender3', true],
		];
	}

	/**
	 * @dataProvider dataonBlock
	 *
	 * @param int $logLevel
	 * @param string $offendingRule
	 * @param bool $expected
	 */
	public function testGetRequestType($logLevel, $offendingRule, $expected) {
		$logger = new Logger(
			$this->logger,
			$logLevel
		);

		$this->logger->expects($expected ? $this->once() : $this->never())
			->method('warning')
			->with('Firewall blocked request due to a matching rule "{offender}"', [
				'app' => 'firewall',
				'offender' => $offendingRule,
			]);

		$logger->onBlock($offendingRule);
	}
}
