<?php
/**
 * ownCloud Workflow
 *
 * @author Joas Schilling <nickvergessen@owncloud.com>
 * @copyright 2015 ownCloud, Inc.
 *
 * This code is covered by the ownCloud Commercial License.
 *
 * You should have received a copy of the ownCloud Commercial License
 * along with this program. If not, see <https://owncloud.com/licenses/owncloud-commercial/>.
 *
 */

namespace OCA\Workflow\Tests\Unit\Engine;

use OCA\Workflow\Engine\Flow;
use OCA\Workflow\Tests\Unit\TestCase;

class FlowTest extends TestCase {
	public function dataId() {
		return [
			[null, 0],
			[0, 0],
			[42, 42],
		];
	}

	/**
	 * @dataProvider dataId
	 * @param mixed $id
	 * @param int $expected
	 */
	public function testId($id, $expected) {
		if ($id === null) {
			$flow = new Flow();
		} else {
			$flow = new Flow($id);
		}
		$this->assertSame($expected, $flow->getId());
	}

	public function testName() {
		$flow = new Flow();
		$this->assertSame('', $flow->getName());
		$this->assertSame($flow, $flow->setName('name1'));
		$this->assertSame('name1', $flow->getName());
		$this->assertSame($flow, $flow->setName('name2'));
		$this->assertSame('name2', $flow->getName());
	}

	public function testType() {
		$flow = new Flow();
		$this->assertSame('', $flow->getType());
		$this->assertSame($flow, $flow->setType('retention'));
		$this->assertSame('retention', $flow->getType());
		$this->assertSame($flow, $flow->setType('workflow_autotagging'));
		$this->assertSame('workflow_autotagging', $flow->getType());
	}

	public function dataTypeInvalid() {
		return [
			[42],
			[[]],
		];
	}

	/**
	 * @dataProvider dataTypeInvalid
	 *
	 * @param mixed $type
	 */
	public function testTypeInvalid($type) {
		$this->expectException(\OutOfBoundsException::class);

		$flow = new Flow();
		$flow->setType($type);
	}

	public function testConditions() {
		$flow = new Flow();
		$this->assertSame([], $flow->getConditions());
		$this->assertSame($flow, $flow->setConditions(['cond1']));
		$this->assertSame(['cond1'], $flow->getConditions());
		$this->assertSame($flow, $flow->setConditions(['cond2']));
		$this->assertSame(['cond2'], $flow->getConditions());
	}

	public function testActions() {
		$flow = new Flow();
		$this->assertSame([], $flow->getActions());
		$this->assertSame($flow, $flow->setActions(['action1']));
		$this->assertSame(['action1'], $flow->getActions());
		$this->assertSame($flow, $flow->setActions(['action2']));
		$this->assertSame(['action2'], $flow->getActions());
	}
}
