<?php
/**
 * ownCloud Workflow
 *
 * @author Joas Schilling <nickvergessen@owncloud.com>
 * @copyright 2016 ownCloud, Inc.
 *
 * This code is covered by the ownCloud Commercial License.
 *
 * You should have received a copy of the ownCloud Commercial License
 * along with this program. If not, see <https://owncloud.com/licenses/owncloud-commercial/>.
 *
 */

namespace OCA\Workflow\Tests\Unit\Engine\Wrapper;

use OCA\Workflow\Engine\Wrapper\CacheWrapper;
use OCA\Workflow\PublicAPI\Event\FileActionInterface;
use Test\TestCase;

class CacheWrapperTest extends TestCase {

	/** @var \OCP\Files\Cache\ICache|\PHPUnit\Framework\MockObject\MockObject */
	protected $cache;

	/** @var \OCA\Workflow\Engine\Plugin|\PHPUnit\Framework\MockObject\MockObject */
	protected $plugin;

	protected function setUp(): void {
		parent::setUp();

		$this->cache = $this->getMockBuilder('OCP\Files\Cache\ICache')
			->disableOriginalConstructor()
			->getMock();

		$this->plugin = $this->getMockBuilder('OCA\Workflow\Engine\Plugin')
			->disableOriginalConstructor()
			->getMock();
	}

	/**
	 * @param string $mountPoint
	 * @param bool $isLocal
	 * @param array $methods
	 * @return CacheWrapper|\PHPUnit\Framework\MockObject\MockObject
	 */
	protected function getInstance($mountPoint, $isLocal, array $methods = []) {
		if (empty($methods)) {
			return new CacheWrapper(
				$this->cache,
				$mountPoint,
				$isLocal,
				$this->plugin
			);
		} else {
			return $this->getMockBuilder('OCA\Workflow\Engine\Wrapper\CacheWrapper')
				->setConstructorArgs([
					$this->cache,
					$mountPoint,
					$isLocal,
					$this->plugin,
				])
				->setMethods($methods)
				->getMock();
		}
	}

	protected function getMockCacheEntry() {
		return $this->getMockBuilder('OCP\Files\Cache\ICacheEntry')
			->disableOriginalConstructor()
			->getMock();
	}

	/*
	 * Cache Wrapper methods
	 * =======================================================================
	 */

	public function dataInsert() {
		return [
			['/admin/', true, 'files/path', ['data1'], 42, $this->getMockCacheEntry(), [2, 4, 16]],
			['/admin/', true, 'files/path', ['data1'], 42, false, [2, 4, 16]],
			['/admin/', true, 'cache/path', ['data1'], 42, null, []],
			['/admin/', false, 'files/path', ['data2'], 23, null, []],
		];
	}

	/**
	 * @dataProvider dataInsert
	 *
	 * @param string $mountPoint
	 * @param bool $isLocal
	 * @param string $path
	 * @param array $data
	 * @param int $fileId
	 * @param false|\OCP\Files\Cache\ICacheEntry $cacheEntry
	 * @param int[] $parents
	 */
	public function testInsert($mountPoint, $isLocal, $path, $data, $fileId, $cacheEntry, array $parents) {
		$instance = $this->getInstance($mountPoint, $isLocal, ['getParentIds']);

		$this->cache->expects($this->once())
			->method('insert')
			->with($path, $data)
			->willReturn($fileId);

		$this->cache->expects($cacheEntry === null ? $this->never() : $this->once())
			->method('get')
			->with($fileId)
			->willReturn($cacheEntry);

		$instance->expects($cacheEntry ? $this->once() : $this->never())
			->method('getParentIds')
			->willReturn($parents);

		$this->plugin->expects($cacheEntry ? $this->once() : $this->never())
			->method('trigger')
			->with(FileActionInterface::CACHE_INSERT, $mountPoint . $path, $fileId, $parents);

		$this->assertSame($fileId, $instance->insert($path, $data));
	}
}
