@api
Feature: add workflow by API

  Background:
    Given user "Alice" has been created with default attributes and skeleton files

  Scenario: autotag files greater than given file size
    Given the administrator has created a "normal" tag with name "JustARegularTagName"
    When the administrator creates a workflow named "test-workflow" setting tag "JustARegularTagName" with these rules using the API
      | rule     | value | operator |
      | filesize | 1024  | greater  |
    And user "Alice" uploads file "filesForUpload/lorem-big.txt" to filenames based on "/big-file.txt" with all mechanisms using the WebDAV API
    And user "Alice" uploads file "filesForUpload/lorem.txt" to filenames based on "/small-file.txt" with all mechanisms using the WebDAV API
    Then file "/big-file.txt-olddav-regular" owned by user "Alice" should have the following tags
      | name                | type   |
      | JustARegularTagName | normal |
    And file "/big-file.txt-newdav-regular" owned by user "Alice" should have the following tags
      | name                | type   |
      | JustARegularTagName | normal |
    And file "/big-file.txt-olddav-oldchunking" owned by user "Alice" should have the following tags
      | name                | type   |
      | JustARegularTagName | normal |
    And file "/big-file.txt-newdav-newchunking" owned by user "Alice" should have the following tags
      | name                | type   |
      | JustARegularTagName | normal |
    But file "/small-file.txt-olddav-regular" owned by "Alice" should have no tags
    And file "/small-file.txt-newdav-regular" owned by "Alice" should have no tags
    And file "/small-file.txt-olddav-oldchunking" owned by "Alice" should have no tags
    And file "/small-file.txt-newdav-newchunking" owned by "Alice" should have no tags

  Scenario: autotag files less than given file size
    Given the administrator has created a "normal" tag with name "JustARegularTagName"
    When the administrator creates a workflow named "test-workflow" setting tag "JustARegularTagName" with these rules using the API
      | rule     | value | operator |
      | filesize | 1024  | less     |
    And user "Alice" uploads file "filesForUpload/lorem-big.txt" to filenames based on "/big-file.txt" with all mechanisms using the WebDAV API
    And user "Alice" uploads file "filesForUpload/lorem.txt" to filenames based on "/small-file.txt" with all mechanisms using the WebDAV API
    Then file "/small-file.txt-olddav-regular" owned by user "Alice" should have the following tags
      | name                | type   |
      | JustARegularTagName | normal |
    And file "/small-file.txt-newdav-regular" owned by user "Alice" should have the following tags
      | name                | type   |
      | JustARegularTagName | normal |
    And file "/small-file.txt-olddav-oldchunking" owned by user "Alice" should have the following tags
      | name                | type   |
      | JustARegularTagName | normal |
    And file "/small-file.txt-newdav-newchunking" owned by user "Alice" should have the following tags
      | name                | type   |
      | JustARegularTagName | normal |
    But file "/big-file.txt-olddav-regular" owned by "Alice" should have no tags
    And file "/big-file.txt-newdav-regular" owned by "Alice" should have no tags
    And file "/big-file.txt-olddav-oldchunking" owned by "Alice" should have no tags
    And file "/big-file.txt-newdav-newchunking" owned by "Alice" should have no tags

  Scenario Outline: autotag files of a given mime-type
    Given using <dav_version> DAV path
    And the administrator has created a "normal" tag with name "JustARegularTagName"
    When the administrator creates a workflow named "test-workflow" setting tag "JustARegularTagName" with these rules using the API
      | rule     | value      | operator |
      | filetype | image/jpeg | equals   |
    When user "Alice" uploads file "filesForUpload/testavatar.jpg" to "/testavatar.jpg" using the WebDAV API
    And user "Alice" uploads file "filesForUpload/testavatar.png" to "/testavatar.png" using the WebDAV API
    Then file "/testavatar.jpg" owned by user "Alice" should have the following tags
      | name                | type   |
      | JustARegularTagName | normal |
    But file "/testavatar.png" owned by "Alice" should have no tags
    Examples:
      | dav_version |
      | old         |
      | new         |

  @issue-141
  Scenario Outline: autotag files of a given mime-type (chunked upload)
    Given using <dav_version> DAV path
    Given the administrator has created a "normal" tag with name "JustARegularTagName"
    When the administrator creates a workflow named "test-workflow" setting tag "JustARegularTagName" with these rules using the API
      | rule     | value      | operator |
      | filetype | image/jpeg | equals   |
    When user "Alice" uploads file "filesForUpload/testavatar.jpg" to "/testavatar-chunked.jpg" with chunks using the WebDAV API
    And user "Alice" uploads file "filesForUpload/testavatar.png" to "/testavatar-chunked.png" with chunks using the WebDAV API
    Then file "/testavatar-chunked.jpg" owned by "Alice" should have no tags
#    Then file "/testavatar-chunked.jpg" owned by user "Alice" should have the following tags
#      | JustARegularTagName | normal |
    But file "/testavatar-chunked.png" owned by "Alice" should have no tags
    Examples:
      | dav_version |
      | old         |
      | new         |
